#!/bin/sh

export TEXTDOMAIN=fbbox
export OUTPUT_CHARSET=UTF-8

#Set default file-backup application for PupShutdown
WORKDIR="/usr/local/PupShutdown"
if [ "`which snap2`" ]; then
 sed -i 's/^.*BACKUP.*$/BACKUP="snap2"/' $WORKDIR/PSD-apps.rc
 echo "#!/bin/bash" > $WORKDIR/defaultapps/backup
 echo "snap2" >> $WORKDIR/defaultapps/backup
elif [ "`which pbackup`" ]; then
 sed -i 's/^.*BACKUP.*$/BACKUP="pbackup"/' $WORKDIR/PSD-apps.rc
 echo "#!/bin/bash" > $WORKDIR/defaultapps/backup
 echo "pbackup" >> $WORKDIR/defaultapps/backup
elif [ "`which gadmin-rsync`" ]; then
 sed -i 's/^.*BACKUP.*$/BACKUP="gadmin-rsync"/' $WORKDIR/PSD-apps.rc
 echo "#!/bin/bash" > $WORKDIR/defaultapps/backup
 echo "gadmin-rsync" >> $WORKDIR/defaultapps/backup
fi

#Set PupShutdown resource files
. /etc/DISTRO_SPECS
sed -i -e 's/^.*NEWLABEL=.*$/NEWLABEL="'"$DISTRO_NAME"'"/' $HOME/.PupShutdown/pupshutdown.rc
cp -f $HOME/.PupShutdown/pupshutdown.rc $HOME/.PupShutdown/pupshutdown-restore.rc
cp -f $WORKDIR/PSD-apps.rc $WORKDIR/PSD-apps2.rc
#[ -f /usr/local/PupShutdown/icons/shutdown48.png ] && rm -f /usr/local/PupShutdown/icons/shutdown48.png

# Add listDD to Thunar right-click menu
if [ "`which thunar 2>/dev/null`" -o "`which Thunar 2>/dev/null`" ]; then
  CONFIG="$HOME/.config/Thunar/uca.xml"
  [ ! -f $HOME/.config/Thunar/uca.xml.bak ] && cp -f $CONFIG $HOME/.config/Thunar/uca.xml.bak
  if [ ! "`grep -a listdd.sh "$CONFIG"`" ]; then
    grep -av '^</actions>' "$CONFIG" > /tmp/tmp
    echo "<action>
	<icon>listdd</icon>
	<name>List Dependencies</name>
	<command>listdd_wrapper %f</command>
	<description>List Dynamic Dependencies</description>
	<patterns>*</patterns>
	<other-files/>
</action>
</actions>" >> /tmp/tmp
    mv /tmp/tmp $CONFIG
  fi
  APPDIR="/usr/local/ListDD"
  ln -sf $APPDIR/icons/listdd.svg /usr/share/icons/hicolor/48x48/apps && gtk-update-icon-cache -f -i /usr/share/icons/hicolor 2>/dev/null
  [ -d /usr/share/Thunar/sendto ] && ln -sf /usr/share/applications/listdd.desktop /usr/share/Thunar/sendto
fi

# Add pArchive to Thunar right-click menu
if [ "`which thunar 2>/dev/null`" -o "`which Thunar 2>/dev/null`" ]; then
  CONFIG="$HOME/.config/Thunar/uca.xml"
  if [ ! "`grep -a pArchive "$CONFIG"`" ]; then
    grep -av '^</actions>' "$CONFIG" > /tmp/tmpfile
    echo "<action>
	<icon>parchive</icon>
	<name>pArchive</name>
	<command>/usr/local/apps/pArchive/AppRun %F</command>
	<description>Archive Manager</description>
	<patterns>*</patterns>
	<directories/>
	<audio-files/>
	<image-files/>
	<other-files/>
	<text-files/>
	<video-files/>
</action>
<action>
	<icon>parchive-info</icon>
	<name>Archive Properties</name>
	<command>/usr/local/apps/archive-properties/AppRun %F</command>
	<description>View Archive Properties</description>
	<patterns>*.7z;*.bfe;*.cb7;*.bz2;*.gz;*.gzi;*.gzip;*.lz;*.lzma;*.lzo;*.xz;*.pet;*.tar;*.tar.7z;*.tar.bz;*.tar.bz2;*.tar.gz;*.tar.lz;*.tar.lzma;*.tar.lzo;*.tar.xz;*.tbz;*.tbz2;*.tgz;*.tlz;*.tlzma;*.txz;*.tzo;*.deb;*.rar;*.RAR;*.rpm;*.RPM;*.zip;*.ZIP;*.iso;*.ISO;*.sfs</patterns>
	<other-files/>
</action>
</actions>" >> /tmp/tmpfile
    mv /tmp/tmpfile $CONFIG
  fi
  APPDIR="/usr/local/parchive"
  ln -sf $APPDIR/icons/parchive.svg $APPDIR/icons/parchive-info.svg /usr/share/icons/hicolor/48x48/apps && gtk-update-icon-cache -f -i /usr/share/icons/hicolor 2>/dev/null
  [ -d /usr/share/Thunar/sendto ] && ln -sf /usr/share/applications/pArchive.desktop /usr/share/Thunar/sendto
fi

# Set jwmdesk first-run autohide parameter to "off" in JWM vgit >=1026 and standard releases >= 2.3.0
if [ -d /usr/local/jwm_config* ]; then
 JWM_HOME="/root/.jwm"
 jwmtray="jwmrc-tray1"
else
 JWM_HOME="/root"
 jwmtray=".jwmrc-tray"
fi

JWM_VER=$(jwm -v | head -n1 | cut -d " " -f2- | cut -d " " -f1 | sed -e 's/[snvgit-]//g')
if [ "`jwm -v | head -n1 | grep -aE 'vgit|vsvn' 2>/dev/null`" ]; then
 if ((`bc <<< "$JWM_VER>=1026"`)); then
  sed -i -e 's#autohide="true"#autohide="off"#' -e 's#autohide="false"#autohide="off"#' $JWM_HOME/$jwmtray
 fi
elif [ "`echo "$JWM_VER" | grep -aE '^2\.3\.[0-9]|^2\.[4-9]|^[3-9]' 2>/dev/null`" ]; then
  sed -i -e 's#autohide="true"#autohide="off"#' -e 's#autohide="false"#autohide="off"#' $JWM_HOME/$jwmtray
fi

#convert menu-button svg icons of jwmdesk to png format if jwm is ancient (vgit<976)
if [ "`jwm -v | head -n1 | grep -aE 'vgit|vsvn' 2>/dev/null`" ]; then
 if ((`bc <<< "$JWM_VER<976"`)); then
  if [ "`which rsvg-convert`" ]; then
    ICONDIR="/usr/local/jwmdesk/jwm_menubutton_icons"
    ICONS=`ls $ICONDIR | grep -a '\.svg'`
    for i in $ICONS
      do
        FILENAME="${i##*/}" #with extension
        FILENAMEnx="${FILENAME%.*}" #no extension
        rsvg-convert -f png -o $ICONDIR/$FILENAMEnx.png $ICONDIR/$i
      done
    rm -f $ICONDIR/*.svg
  fi
 fi
fi

# Check missing images in icon themes
THEMES=`ls /usr/local/lib/X11/themes | sort`
for i in $THEMES 
  do
    if [ -d /usr/local/lib/X11/themes/$i ]; then
     if [ -f /usr/local/lib/X11/themes/$i/games24.png ] && [ ! -f /usr/local/lib/X11/themes/$i/games48.png ]; then
      cp -f /usr/local/lib/X11/themes/$i/games24.png /tmp/tmp
      mv -f /tmp/tmp /usr/local/lib/X11/themes/$i/games48.png
     fi
     if [ -f /usr/local/lib/X11/themes/$i/pc24.png ] && [ ! -f /usr/local/lib/X11/themes/$i/pc48.png ]; then
      cp -f /usr/local/lib/X11/themes/$i/pc24.png /tmp/tmp
      mv -f /tmp/tmp /usr/local/lib/X11/themes/$i/pc48.png
     fi
     if [ -f /usr/local/lib/X11/themes/$i/shutdown24.png ] && [ ! -f /usr/local/lib/X11/themes/$i/shutdown48.png ]; then
      cp -f /usr/local/lib/X11/themes/$i/shutdown24.png /tmp/tmp
      mv -f /tmp/tmp /usr/local/lib/X11/themes/$i/shutdown48.png
     fi
     if [ -f /usr/local/lib/X11/themes/$i/utility24.png ] && [ ! -f /usr/local/lib/X11/themes/$i/utility48.png ]; then
      cp -f /usr/local/lib/X11/themes/$i/utility24.png /tmp/tmp
      mv -f /tmp/tmp /usr/local/lib/X11/themes/$i/utility48.png
     fi
     if [ -f /usr/local/lib/X11/themes/$i/x24.png ] && [ ! -f /usr/local/lib/X11/themes/$i/x48.png ]; then
      cp -f /usr/local/lib/X11/themes/$i/x24.png /tmp/tmp
      mv -f /tmp/tmp /usr/local/lib/X11/themes/$i/x48.png
     fi
     if [ -f /usr/local/lib/X11/themes/$i/x.png ] && [ ! -f /usr/local/lib/X11/themes/$i/x48.png ]; then
      cp -f /usr/local/lib/X11/themes/$i/x.png /tmp/tmp
      mv -f /tmp/tmp /usr/local/lib/X11/themes/$i/x48.png
     fi
    fi
  done
  [ ! -f /usr/local/lib/X11/pixmaps/pc48.png ] && [ -f /usr/local/lib/X11/pixmaps/pc24.png ] && cp -f /usr/local/lib/X11/pixmaps/pc24.png /tmp/tmp && mv -f /tmp/tmp /usr/local/lib/X11/pixmaps/pc48.png
  [ ! -f /usr/local/lib/X11/pixmaps/shutdown48.png ] && [ -f /usr/local/lib/X11/pixmaps/shutdown24.png ] && cp -f /usr/local/lib/X11/pixmaps/shutdown24.png /tmp/tmp && mv -f /tmp/tmp /usr/local/lib/X11/pixmaps/shutdown48.png

# Update gtkdialog path for treeicons
DTDIR="/usr/share/applications"
if [[ `ls /usr/local/share/applications/ 2>/dev/null` ]]; then 
	DTDIR="${DTDIR} /usr/local/share/applications"
fi
grep -R "^Icon=" $DTDIR --include="*.desktop" 2>/dev/null | cut -d ':' -f1 | awk -F'/' '{print $NF}' | sort -fu > /tmp/tmp
while read -r line
 do
	ICON=$(grep -a -m1 '^Icon=' "$DTDIR"/"$line" 2>/dev/null | cut -d'=' -f2-)
	ICONNAME="${ICON##*/}" #with extension
	[ $(echo "$ICON" | grep -a '^/') ] && [ ! -f /usr/share/pixmaps/"$ICONNAME" ] && ln -snf "$ICON" /usr/share/pixmaps/$ICONNAME
 done < /tmp/tmp

X11PIXMAPS=$(ls /usr/local/lib/X11/pixmaps | grep -aE '\.[psx][npv][gm]')
for i in $X11PIXMAPS
 do
	[ ! -h /usr/local/lib/X11/pixmaps/"$i" ]  && [ ! -h /usr/share/pixmaps/"$i"  ] && ln -snf /usr/local/lib/X11/pixmaps/"$i" /usr/share/pixmaps/"$i"
 done

# Create icon symlinks to support non-path treeicons in Slacko-6.3.0.X (not required for subsequent Slackos)
if [[ $(echo $DISTRO_NAME | grep -i slacko) ]]; then
 if [[ $(echo $DISTRO_VERSION | grep '6\.3\.0') ]]; then
  ls /usr/share/pixmaps/puppy | sort > /tmp/tmp
   while read -r icon
    do
      [ ! -f /usr/share/pixmaps/"$icon" ] && ln -snf /usr/share/pixmaps/puppy/"$icon" /usr/share/pixmaps/
    done < /tmp/tmp
 fi
fi

# Protect treeicons by removing broken image symlinks
find -L /usr/share/pixmaps /usr/share/icons -type l -delete 2>/dev/null

# Adjust opening JWMDesk GUI size for Quirky
if [[ $(echo $DISTRO_NAME | grep -iE 'quirky|easy') ]]; then
 mkdir -p /usr/local/jwmdesk/preferences
 echo "515" > /usr/local/jwmdesk/preferences/window_width
fi

# Support xdialog dselect buttons for pArchive extract
[ ! -d $HOME/Desktop ] && mkdir $HOME/Desktop
[ ! -f $HOME/Documents ] && ln -sf $HOME/my-documents $HOME/Documents

# Support postscript viewing in some pups
[ ! "`which gv`" ] && cp -f /tmp/gv /usr/bin
[ ! "`which ghostview`" ] && ln -sf /usr/bin/gv /usr/bin/ghostview
EVINCESIZE=`stat -c %s /usr/bin/evince`
[ "`which evince`" ] && [ "$EVINCESIZE" != "551" ] && [ ! "`which epdfview`" ] && ln -sf /usr/bin/evince /usr/bin/epdfview
[ "`which qpdfview`" ] && [ ! "`which epdfview`" ] && ln -sf /usr/bin/qpdfview /usr/bin/epdfview

# Update Manage-favorites .desktop file
echo -e "[Desktop Entry]\nEncoding=UTF-8\nName=✫Manage menu favorites\nName[de]=✫Verwalten favoriten\nName[es]=✫Administrar favoritas\nName[fr]=✫Gérer favoris\nName[it]=✫Gestire preferiti\nIcon=/usr/local/PupMenu/icons/pmedit48.png\nComment=$(gettext 'Add or remove menu favorites')\nExec=ManageFavorites\nTerminal=false\nType=Application\nCategories=Favorite;" > /usr/share/applications/✫Manage-favorites.desktop

# Do not start pmcputemp in FbBox (tahrpup/xenialpup)
[ -f $HOME/Startup/pmcputemp1 ] && sed -i 's/^.*exec pmcputemp.*$/[ "`pidof jwm`" ] \&\& exec pmcputemp \&/' $HOME/Startup/pmcputemp1

# Update font cache
if [ -d /usr/share/fonts/default/TTF ];then
 cd /usr/share/fonts/default/TTF
 mkfontscale
 mkfontdir
 fc-cache -r
fi

# First-run flag
touch /tmp/FbBox-firstrun

# First-run dialog
Xdialog --title Alert --beep --msgbox "\n $(gettext 'FbBox-5.0 files are installed!') \n\n $(gettext 'Please go to Puppy Menu -> Desktop -> WM Switcher') \n" 0x0+200+100

#END
